@@ -4,10 +4,10 @@
 
 ;; Author:           Stefan Möding <stm@kill-9.net>
 ;; Maintainer:       Stefan Möding <stm@kill-9.net>
-;; Package-Version: 20260123.1700
-;; Package-Revision: 6c3082e49033
+;; Package-Version: 20260223.1132
+;; Package-Revision: f287c44f3576
 ;; Created:          <2024-03-02 13:05:03 stm>
-;; Updated:          <2026-01-23 17:55:13 stm>
+;; Updated:          <2026-02-23 12:31:32 stm>
 ;; URL:              https://github.com/smoeding/puppet-ts-mode
 ;; Keywords:         languages
 ;; Package-Requires: ((emacs "29.1"))
@@ -44,6 +44,9 @@
 ;;   Puppet syntax elements like comments, strings, variables, constants,
 ;;   keywords, resource types and their metaparameters.  Syntax errors can be
 ;;   shown using a warning face by setting `treesit-font-lock-level' to 4.
+;;   Some generic syntax elements (comments, strings, numbers,...) use the
+;;   default Emacs faces.  This allows other packages like `flyspell' to
+;;   spell-check comments and strings without any additional setup.
 ;;
 ;; Indentation: Automatic indentation according to the Puppet coding
 ;;   standards is provided.
@@ -75,8 +78,9 @@
 ;;   current buffer in noop-mode with `puppet-ts-apply' (bound to "C-c C-c").
 ;;
 ;; The package uses a Tree-sitter library to parse Puppet code and you need
-;; to install the appropriate parser.  This can be done by using this Elisp
-;; code:
+;; to install the appropriate parser (which is defined by the constant
+;; `puppet-ts-mode-treesit-language-source').  This can be done by using
+;; this Elisp code:
 ;;
 ;;    (require 'puppet-ts-mode)
 ;;    (puppet-ts-mode-install-grammar)
@@ -129,7 +133,7 @@
   '("alias" "audit" "before" "consume" "export" "loglevel" "noop"
     "notify" "require" "schedule" "stage" "subscribe" "tag" "ensure")
   "Metaparameter attributes for all resource types.
-Strictly speakting, \"ensure\" is not a real metaparameter, but it
+Strictly speaking, \"ensure\" is not a real metaparameter, but it
 is added here because it is common and important.")
 
 ;; https://www.puppet.com/docs/puppet/latest/function.html
@@ -212,26 +216,6 @@ automatic alignment if electric."
 
 ;;; Faces
 
-(defface puppet-ts-comment
-  '((t :inherit font-lock-comment-face))
-  "Face for comments in Puppet."
-  :group 'puppet-ts)
-
-(defface puppet-ts-string
-  '((t :inherit font-lock-string-face))
-  "Face for strings in Puppet."
-  :group 'puppet-ts)
-
-(defface puppet-ts-regexp
-  '((t :inherit font-lock-regexp-face))
-  "Face for regular expressions."
-  :group 'puppet-ts)
-
-(defface puppet-ts-escape
-  '((t :inherit font-lock-escape-face))
-  "Face for escape sequences."
-  :group 'puppet-ts)
-
 (defface puppet-ts-keyword
   '((t :inherit font-lock-keyword-face))
   "Face for keywords in Puppet."
@@ -272,26 +256,6 @@ automatic alignment if electric."
   "Face for the name of a function being called in Puppet."
   :group 'puppet-ts)
 
-(defface puppet-ts-operator
-  '((t :inherit font-lock-operator-face))
-  "Face for operators."
-  :group 'puppet-ts)
-
-(defface puppet-ts-negation-char
-  '((t :inherit font-lock-negation-char-face))
-  "Face for negation characters."
-  :group 'puppet-ts)
-
-(defface puppet-ts-number
-  '((t :inherit font-lock-number-face))
-  "Face for numbers."
-  :group 'puppet-ts)
-
-(defface puppet-ts-warning
-  '((t :inherit font-lock-warning-face))
-  "Face for language errors found by the parser."
-  :group 'puppet-ts)
-
 
 ;; Font-Lock
 
@@ -313,17 +277,17 @@ automatic alignment if electric."
   `( ;;
     :feature comment
     :language puppet
-    ((comment) @puppet-ts-comment)
+    ((comment) @font-lock-comment-face)
 
     :feature string
     :language puppet
-    (((double_quoted_string) @puppet-ts-string)
-     ((single_quoted_string) @puppet-ts-string)
-     ((heredoc_body) @puppet-ts-string))
+    (((double_quoted_string) @font-lock-string-face)
+     ((single_quoted_string) @font-lock-string-face)
+     ((heredoc_body) @font-lock-string-face))
 
     :feature regexp
     :language puppet
-    ((regex) @puppet-ts-regexp)
+    ((regex) @font-lock-regexp-face)
 
     :feature string-interpolation
     :language puppet
@@ -333,9 +297,9 @@ automatic alignment if electric."
     :feature escape-sequence
     :language puppet
     :override t
-    ((double_quoted_string (escape_sequence) @puppet-ts-escape)
-     (single_quoted_string (escape_sequence) @puppet-ts-escape)
-     (heredoc_body (escape_sequence) @puppet-ts-escape))
+    ((double_quoted_string (escape_sequence) @font-lock-escape-face)
+     (single_quoted_string (escape_sequence) @font-lock-escape-face)
+     (heredoc_body (escape_sequence) @font-lock-escape-face))
 
     :feature variable
     :language puppet
@@ -348,7 +312,7 @@ automatic alignment if electric."
 
     :feature number
     :language puppet
-    ((number) @puppet-ts-number)
+    ((number) @font-lock-number-face)
 
     :feature definition
     :language puppet
@@ -407,21 +371,21 @@ automatic alignment if electric."
 
     :feature operator
     :language puppet
-    ((unary operator: "!" @puppet-ts-negation-char)
-     (unary operator: _  @puppet-ts-operator)
-     (binary operator: _ @puppet-ts-operator))
+    ((unary operator: "!" @font-lock-negation-char-face)
+     (unary operator: _  @font-lock-operator-face)
+     (binary operator: _ @font-lock-operator-face))
 
     :feature error
     :language puppet
     :override t
-    ((ERROR) @puppet-ts-warning))
+    ((ERROR) @font-lock-warning-face))
   "`treesit-font-lock-settings' for `puppet-ts-mode'.")
 
 
 ;; Indentation
 
 (defcustom puppet-ts-indent-level 2
-  "Number of spaces for each indententation step."
+  "Number of spaces for each indentation step."
   :group 'puppet-ts
   :type 'integer
   :safe 'integerp)
@@ -509,7 +473,7 @@ type must match one of the given type names."
 ;; Imenu
 
 (defun puppet-ts--resource-imenu-name (node)
-  "Return the imenu title for NODE."
+  "Return the Imenu title for NODE."
   (let ((type (treesit-node-type node)))
     (cond ((string-equal type "resource_type")
            (concat (puppet-ts-resource-type node)
@@ -952,7 +916,7 @@ without the \"$\" prefix."
 (defcustom puppet-ts-metaparameters
   '("alias" "audit" "before" "loglevel" "noop" "notify" "require" "schedule"
     "stage" "subscribe" "tag")
-  "A list of the Puppet metaparemeters used for completion."
+  "A list of the Puppet metaparameters used for completion."
   :group 'puppet-ts
   :type '(repeat string))
 
@@ -1468,7 +1432,7 @@ By convention a Puppet manifest only has a single definition of
 a class, defined type or function.  So the navigation function
 `beginning-of-defun' and `end-of-defun' would normally only jump
 to the beginning or the end of the buffer.  This does not provide
-any benefit and so the mode uses the associated keybindings to go
+any benefit and so the mode uses the associated key bindings to go
 to the preceding (\\[treesit-beginning-of-defun]) or the following (\\[treesit-end-of-defun]) resource
 declaration.  Putting the region around this declaration by
 calling the function `mark-defun' (\\[mark-defun]) comes for free.
